@@ -533,20 +533,20 @@ def showSchema(gClient,gSpace,tabuEdgeList=["Alias","School"],tabuTagList=["alia
         tagAttrDict={}
         tagCountDict={}
         for tagIndexItem in tagIndexList:
-            if tagIndexItem not in tabuTagList:
                 tagIndexDf=wrapNebula2Df(gClient.execute_query("DESCRIBE TAG INDEX {}".format(tagIndexItem)))
                 tagAttrList=tagIndexDf["Field"].values.flatten().tolist()
                 for tagAttrItem in tagAttrList:
                     for tagItem in tagList:
-                        tagSearchDf=wrapNebula2Df(gClient.execute_query("LOOKUP ON {tagType} WHERE {tagType}.{tagAttr}!='不可能的名字'|YIELD COUNT($-.VertexID) AS nodeCount".format(
-                                                                                                                                                        tagType=tagItem,
-                                                                                                                                                        tagAttr=tagAttrItem
-                                                                                                                                                    ))).replace("",np.nan).replace("null",np.nan).dropna()
-                        if tagSearchDf.shape[0]>0:
-                            tagCountVal=tagSearchDf["nodeCount"].values[0]
-                            if tagCountVal>0:
-                                tagAttrDict[tagItem]=tagAttrDict.get(tagItem,[])+[tagAttrItem]
-                                tagCountDict[tagItem]=tagCountVal
+                        if tagItem not in tabuTagList:
+                            tagSearchDf=wrapNebula2Df(gClient.execute_query("LOOKUP ON {tagType} WHERE {tagType}.{tagAttr}!='不可能的名字'|YIELD COUNT($-.VertexID) AS nodeCount".format(
+                                                                                                                                                            tagType=tagItem,
+                                                                                                                                                            tagAttr=tagAttrItem
+                                                                                                                                                        ))).replace("",np.nan).replace("null",np.nan).dropna()
+                            if tagSearchDf.shape[0]>0:
+                                tagCountVal=tagSearchDf["nodeCount"].values[0]
+                                if tagCountVal>0:
+                                    tagAttrDict[tagItem]=tagAttrDict.get(tagItem,[])+[tagAttrItem]
+                                    tagCountDict[tagItem]=tagCountVal
     
     edgeDf=wrapNebula2Df(gClient.execute_query("SHOW EDGES")).dropna()
     if edgeDf.shape[0]>0:
@@ -794,7 +794,7 @@ if __name__=="__main__":
     #               )
 
     start=time.time()
-    tagList,htList=showSchema(srcClient,"post_skill_school_ianxu")
+    tagList,htList=showSchema(srcClient,"post_skill_school_ianxu",tabuTagList=["School","Alias"])
     end=time.time()
 
     print(end-start)
