@@ -126,8 +126,10 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
     if csvFolder[-1]=="/":
         csvFolder=csvFolder[:-1]
     
-    for vertexI,_ in tqdm.tqdm(enumerate(rawSchemaJson["vertex"]),desc="vertex"):
+    vertexI=0
+    while vertexI<len(rawSchemaJson["vertex"]):
         rawSchemaJson["vertex"][vertexI]["file_path"]=csvFolder+"/"+rawSchemaJson["vertex"][vertexI]["file_name"]
+        print("vertex:",rawSchemaJson["vertex"][vertexI]["file_path"])
         csvDfItem=pd.read_csv(rawSchemaJson["vertex"][vertexI]["file_path"]).drop_duplicates()
         csvDfItem[rawSchemaJson["vertex"][vertexI]["id_col"]]=csvDfItem[rawSchemaJson["vertex"][vertexI]["id_col"]].astype(str)
         vertexType=rawSchemaJson["vertex"][vertexI]["node_type"]
@@ -276,6 +278,7 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
                     else:
                         csvDfItem[colItem]=csvDfItem[colItem].fillna(0.0)
         
+            
         csvDfItem.to_csv(rawSchemaJson["vertex"][vertexI]["file_path"],index=None)
         rawSchemaJson["vertex"][vertexI]["old_id_col"]=rawSchemaJson["vertex"][vertexI]["id_col"]
         rawSchemaJson["vertex"][vertexI]["id_col"]="newMadeSysID"
@@ -286,9 +289,19 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
             vertexItemDf=pd.read_csv(rawSchemaJson["vertex"][vertexI]["file_path"])
             CPAttrTypeDict=evalDataType(vertexItemDf)
             rawSchemaJson["vertex"][vertexI]["attr_type_map"]=CPAttrTypeDict
+            
+        if csvDfItem.shape[0]==0:
+            print(rawSchemaJson["vertex"][edgeI]["file_path"])
+            os.remove(rawSchemaJson["vertex"][vertexI]["file_path"])
+            rawSchemaJson["vertex"].pop(vertexI)
+            vertexI-=1
+            
+        vertexI+=1
 
-    for edgeI,_ in tqdm.tqdm(enumerate(rawSchemaJson["edge"]),desc="edge"):
+    edgeI=0
+    while edgeI<len(rawSchemaJson["edge"]):
         rawSchemaJson["edge"][edgeI]["file_path"]=csvFolder+"/"+rawSchemaJson["edge"][edgeI]["file_name"]
+        print("edge:",rawSchemaJson["edge"][edgeI]["file_path"])
         csvDfItem=pd.read_csv(rawSchemaJson["edge"][edgeI]["file_path"]).drop_duplicates()
         srcType=rawSchemaJson["edge"][edgeI]["src_type"]
         tgtType=rawSchemaJson["edge"][edgeI]["tgt_type"]
@@ -397,11 +410,12 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
                     queryStrList.append(queryItemStr)
                 queryStr=" UNION ".format(queryStrList)
                 htItemDf=wrapNebula2Df(gClient.execute_query(queryStr))
-                newHTItemList=json.loads(htItemDf.to_json(orient="records"))
-                for keyItem in attrList:
-                    if newHTItemList[0][keyItem] is None or np.nan(newHTItemList[0][keyItem]) or newHTItemList[0][keyItem]=="null":
-                        newHTItemList[0][keyItem]=htItem[keyItem]
-                newHTList+=newHTItemList
+                if htItemDf.shape[0]>0:
+                    newHTItemList=json.loads(htItemDf.to_json(orient="records"))
+                    for keyItem in attrList:
+                        if newHTItemList[0][keyItem] is None or np.nan(newHTItemList[0][keyItem]) or newHTItemList[0][keyItem]=="null":
+                            newHTItemList[0][keyItem]=htItem[keyItem]
+                    newHTList+=newHTItemList
             csvDfItem=pd.DataFrame(newHTList)
             
             for colItem in edgeAttrTypeDict:
@@ -448,6 +462,14 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
             CPAttrTypeDict=evalDataType(edgeItemDf)
             rawSchemaJson["edge"][edgeI]["attr_type_map"]=CPAttrTypeDict
     
+        if csvDfItem.shape[0]==0:
+            print(rawSchemaJson["edge"][edgeI]["file_path"])
+            os.remove(rawSchemaJson["edge"][edgeI]["file_path"])
+            rawSchemaJson["edge"].pop(edgeI)
+            edgeI-=1
+        
+        edgeI+=1
+        
     return rawSchemaJson
 
 def buildGraphDB(gClient,uploadSchemaJson,realDbName=None,force=False):
