@@ -163,13 +163,11 @@ def createSchemaFromSchemaJson(schemaJson,graphClient):
     createTagIndexErrCode=0
     rebuildTagIndexErrCode=0
     createEdgeErrCode=0
-    schemaJson["vertex"]=schemaJson.get("vertex",[])+[{"node_type":"Alias","old_id_col":"Name","attr_type_map":{"Name":"string"}}]
     if "vertex" in schemaJson: # 构建节点schema
         schemaTagList=schemaJson["vertex"]
         for schemaTagItem in schemaTagList:
             nodeType=schemaTagItem["node_type"]
             nodeIdAttr=schemaTagItem["old_id_col"]
-            schemaTagItem["attr_type_map"]={**schemaTagItem["attr_type_map"],**{"sourceName":"string"}}
             nodeAttrStr=",".join([" ".join([attrKey,schemaTagItem["attr_type_map"][attrKey]])+" DEFAULT {}".format(attrTypeNullDict[schemaTagItem["attr_type_map"][attrKey]]) 
                                     for attrKey in schemaTagItem["attr_type_map"]])
             
@@ -194,22 +192,52 @@ def createSchemaFromSchemaJson(schemaJson,graphClient):
             )
             rebuildTagIndexReq=graphClient.execute_query(rebuildTagIndexStr)
             rebuildTagIndexErrCode=rebuildTagIndexReq.error_code
-    schemaJson["vertex"].pop(-1)
-    
-    schemaJson["edge"]=schemaJson.get("edge",[])+[{"edge_type":"aliasNameOf","attr_type_map":{}}]
+
+            attrList=[attrItem for attrItem in schemaTagItem["attr_type_map"]]
+            for attrLenI in range(1,len(attrList)+1):
+                for combItem in combinations(attrList,attrLenI):
+                    tagIndexName="{}_{}_index".format(
+                                                        nodeType,
+                                                        "_".join(combItem)
+                                                    )
+                    createTagIndexStr="CREATE TAG INDEX {} ON {}({})".format(
+                                                                                tagIndexName,
+                                                                                nodeType,
+                                                                                ",".join(combItem)
+                                                                            )
+                    createTagIndexReq=gClient.execute_query(createTagIndexStr)
+
+                    rebuildTagIndexStr="REBUILD TAG INDEX {} OFFLINE".format(tagIndexName)
+                    rebuildTagIndexReq=gClient.execute_query(rebuildTagIndexStr)
+
+
     if "edge" in schemaJson: # 构建关系schema
         schemaEdgeList=schemaJson["edge"]
         for schemaEdgeItem in schemaEdgeList:
             edgeType=schemaEdgeItem["edge_type"]
-            schemaEdgeItem["attr_type_map"]={**schemaEdgeItem.get("attr_type_map",{}),**{"sourceName":"string"}}
-            edgeAttrStr=",".join([" ".join([attrKey,schemaEdgeItem.get("attr_type_map",{})[attrKey]])+" DEFAULT {}".format(attrTypeNullDict[schemaEdgeItem["attr_type_map"][attrKey]]) 
+            edgeAttrStr=",".join([" ".join([attrKey,schemaEdgeItem["attr_type_map"][attrKey]])+" DEFAULT {}".format(attrTypeNullDict[schemaEdgeItem["attr_type_map"][attrKey]]) 
                                     for attrKey in schemaEdgeItem["attr_type_map"]])
 
             createEdgeStr="CREATE EDGE IF NOT EXISTS {}({})".format(edgeType,edgeAttrStr)
             createEdgeReq=graphClient.execute_query(createEdgeStr)
             createEdgeErrCode=createEdgeReq.error_code
             
-    schemaJson["edge"].pop(-1)
+            attrList=[attrItem for attrItem in schemaTagItem["attr_type_map"]]
+            for attrLenI in range(1,len(attrList)+1):
+                for combItem in combinations(attrList,attrLenI):
+                    edgeIndexName="{}_{}_index".format(
+                                                        edgeType,
+                                                        "_".join(combItem)
+                                                    )
+                    createEdgeIndexStr="CREATE EDGE INDEX {} ON {}({})".format(
+                                                                                edgeIndexName,
+                                                                                edgeType,
+                                                                                ",".join(combItem)
+                                                                            )
+                    createEdgeIndexReq=gClient.execute_query(createEdgeIndexStr)
+
+                    rebuildEdgeIndexStr="REBUILD TAG INDEX {} OFFLINE".format(edgeIndexName)
+                    rebuildEdgeIndexReq=gClient.execute_query(rebuildEdgeIndexStr)
 
     return createTagErrCode,createTagIndexErrCode,rebuildTagIndexErrCode,createEdgeErrCode
             
