@@ -14,8 +14,8 @@ def importData(gUrl,taskId="12",cookie=""):
         'Accept': 'application/json, text/plain, */*',
         'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/92.0.4515.107 Safari/537.36 Edg/92.0.902.62',
         'Content-Type': 'application/json',
-        'Origin': 'http://9.135.95.249:7001',
-        'Referer': 'http://9.135.95.249:7001/import',
+        'Origin': gUrl,
+        'Referer': '{}/import'.format(gUrl),
         'Accept-Language': 'zh-CN,zh;q=0.9,en;q=0.8,en-GB;q=0.7,en-US;q=0.6',
         'Cookie': cookie
     }
